@@ -82,7 +82,7 @@ from debputy.plugin.api.impl import (
     find_related_implementation_files_for_plugin,
     parse_json_plugin_desc,
 )
-from debputy.dh_migration.migration import migrate_from_dh, _check_migration_target
+from debputy.dh_migration.migration import perform_migration, _check_migration_target
 from debputy.dh_migration.models import AcceptableMigrationIssues
 from debputy.dh.debhelper_emulation import (
     dhe_pkgdir,
@@ -1070,7 +1070,7 @@ def _json_output(data: Any) -> None:
 
 @ROOT_COMMAND.register_subcommand(
     "migrate-from-dh",
-    help_description='Generate/update manifest from a "dh $@" using package',
+    help_description="Perform a named migration of a source package",
     argparser=[
         add_arg(
             "--acceptable-migration-issues",
@@ -1084,12 +1084,12 @@ def _json_output(data: Any) -> None:
         add_arg(
             "--migration-target",
             dest="migration_target",
+            metavar="MIGRATION_TARGET",
             action="store",
             choices=MIGRATORS,
             type=str,
             default=None,
-            help="Continue the migration even if this/these issues are detected."
-            " Can be set to ALL (in all upper-case) to accept all issues",
+            help="The desired migration target",
         ),
         add_arg(
             "--no-act",
@@ -1097,18 +1097,25 @@ def _json_output(data: Any) -> None:
             dest="destructive",
             action="store_false",
             default=None,
-            help="Do not perform changes.  Existing manifest will not be overridden",
+            help="Do not perform changes.  Existing packaging files will not be changed",
         ),
         add_arg(
             "--apply-changes",
             dest="destructive",
             action="store_true",
             default=None,
-            help="Perform changes.  The debian/debputy.manifest will updated in place if exists",
+            help="Perform changes.  The packaging files will updated in place",
+        ),
+        add_arg(
+            "--ignore-vcs",
+            dest="ignore_vcs",
+            action="store_true",
+            default=None,
+            help="Do not look for nor use a version control system (such as `git`)",
         ),
     ],
 )
-def _migrate_from_dh(context: CommandContext) -> None:
+def _migrate_source_package(context: CommandContext) -> None:
     context.must_be_called_in_source_root()
     parsed_args = context.parsed_args
     resolved_migration_target = _check_migration_target(
@@ -1122,13 +1129,17 @@ def _migrate_from_dh(context: CommandContext) -> None:
             i for x in parsed_args.acceptable_migration_issues for i in x.split(",")
         )
     )
-    migrate_from_dh(
+
+    migrators = MIGRATORS[resolved_migration_target]
+    perform_migration(
         _output_styling(context.parsed_args, sys.stdout),
         manifest,
         acceptable_migration_issues,
         parsed_args.destructive,
         resolved_migration_target,
         lambda p: context.parse_manifest(manifest_path=p),
+        migrators,
+        ignore_vcs=parsed_args.ignore_vcs,
     )
 
 
